<<<<<<< HEAD
# hierarch

## A Hierarchical Resampling Package for Python

Version 0.1.3

hierarch is a package for hierarchical resampling (bootstrapping, permutation, jackknifing) datasets in Python. Because for loops are ultimately intrinsic to cluster-aware resampling, hierarch uses Numba to accelerate many of its key functions.

hierarch has several functions for performing resampling-based hypothesis tests on hierarchical data. Additionally, hierarch can be used to construct power analyses for hierarchical experimental designs. 

### Dependencies
* numpy
* numba
* scipy (for power analysis)
* sympy (for jackknifing)

### Installation

The easiest way to install hierarch is via PyPi. 

```pip install hierarch```

Alternatively, you can install from Anaconda.

```conda install -c rkulk111 hierarch```

### Documentation

There will someday be documentation to walk users through setting up and performing a hypothesis test.


=======
# hierarch

## A Hierarchical Resampling Package for Python

Version 0.1.2

hierarch is a package for hierarchical resampling (bootstrapping, permutation, jackknifing) datasets in Python. Because for loops are ultimately intrinsic to cluster-aware resampling, hierarch uses Numba to accelerate many of its key functions.

hierarch has several functions for performing resampling-based hypothesis tests on hierarchical data. Additionally, hierarch can be used to construct power analyses for hierarchical experimental designs. 

### Dependencies
* numpy
* numba
* scipy (for power analysis)
* sympy (for jackknifing)

>>>>>>> cdde8466095c8045aa441e136d1ba56fd0326e9d
